@@ -81,7 +81,8 @@ g_mime_filter_get_type (void)
 			(GInstanceInitFunc) g_mime_filter_init,
 		};
 		
-		type = g_type_register_static (G_TYPE_OBJECT, "GMimeFilter", &info, 0);
+		type = g_type_register_static (G_TYPE_OBJECT, "GMimeFilter",
+					       &info, G_TYPE_FLAG_ABSTRACT);
 	}
 	
 	return type;
